# odbindex

Generate OBLAC Drives Bundle Index Page.

## Install

    $ python3 -m pip install odbindex

## Usage

    $ GITHUB_SYNAPTICON_ACCESS_TOKEN=a21f42faace60a789e74f3c2c2f468f2732011ca odbindex > odbindex.html
